@@ -30,7 +30,7 @@
 set -e
 
 # Uncomment next line to debug
-# set -x
+set -x
 
 #DEBUG
 #To test with different library versions, you can use different install path, for instance:
@@ -149,7 +149,7 @@ init() {
 
     echo "===== CamiTK environment ====="
     if [ $# -lt 1 -o "$1" != "-inbuild" ] ; then
-        echo "[OK] Test using installed camitk version"
+        echo "[OK] Test using installed CamiTK version"
         inBuild=0
         # for installed camitk, just run the corresponding executables
         camitkGenerator=camitk-cepgenerator
@@ -197,10 +197,22 @@ init() {
             echo "===== Checking camitk-config-debug ====="
             checkCamiTKConfig=$(checkcommand $camitkConfig)
             echo "$checkCamiTKConfig"
+            if [ "$checkCamiTKConfig" != "[OK]" ] ; then            
+                echo "[FAIL] Error: cannot find camitk-config nor camitk-config-debug"
+            else
+                buildType="Debug"
+            fi
         fi
     else
         echo "[OK] executable camitk-config found"
+        buildType="Release"
     fi
+
+    if [[ "$osName" == "Windows" ]]; then
+        echo "==== Windows build type ===="
+        echo "$buildType"
+    fi
+    
     echo "===== camitk-config configuration ====="
     echo "[OK] using $camitkConfig on $osName"
 
@@ -262,10 +274,8 @@ generateConfigureAndMake() {
   cd build
   echo "===== Configuring... ====="
   if [[ "$osName" == "Windows" ]]; then
-    # use the currently supported visual studio version (64 bit) with the Debug config
-    #cmake $CMAKE_OPTIONS -Wno-dev -G "Visual Studio 16 2019" -A x64 --config Debug ../$srcDirName > ../cmake-log 2> ../cmake-error
     # choose the default msvc version and config from current install
-    cmake $CMAKE_OPTIONS -Wno-dev --config Debug ../$srcDirName > ../cmake-log 2> ../cmake-error
+    cmake $CMAKE_OPTIONS -Wno-dev  ../$srcDirName > ../cmake-log 2> ../cmake-error
   else
     cmake $CMAKE_OPTIONS ../$srcDirName > ../cmake-log 2> ../cmake-error
   fi
@@ -280,7 +290,7 @@ generateConfigureAndMake() {
 
   echo "===== building... ====="
   if [[ "$osName" == "Windows" ]]; then
-    cmake --build . --config Debug --parallel 9 > ../make-log 2> ../make-error
+    cmake --build . --config $buildType --parallel 9 > ../make-log 2> ../make-error
   else
     # build (parallel)
     make -j9 > ../make-log 2> ../make-error
